twitch

package
v0.0.0-...-2d01341 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 30, 2021 License: MIT Imports: 6 Imported by: 0

README

what is terraform

Terraform is an infrastruct provisioning tool.

That essentially means... if you want to get/create something. You can allow terraform to do this for you

Terraform takes config files

resource "twitch" "channel_point" {
    name = "dance for 5 seconds"
    cost = 4000
}

terraform apply

creates that channel point and remembers that it created it

terraform destory

it will remove that channel point

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Provider

func Provider() *schema.Provider

Provider -

Types

This section is empty.

Jump to